pub struct AuthHandler { /* private fields */ }Expand description
Authentication handler
Implementations
Sourceimpl AuthHandler
impl AuthHandler
Sourcepub fn new(config: AuthConfig) -> Self
pub fn new(config: AuthConfig) -> Self
Create a new auth handler with the given configuration
Sourcepub fn from_config_with_env(config: AuthConfig) -> Self
pub fn from_config_with_env(config: AuthConfig) -> Self
Load configuration with environment variable overrides
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Check if authentication is enabled
Sourcepub fn is_protected(&self, path: &str) -> bool
pub fn is_protected(&self, path: &str) -> bool
Check if a path is protected
Sourcepub fn login_path(&self) -> &str
pub fn login_path(&self) -> &str
Get the login path
Sourcepub fn after_login_path(&self) -> &str
pub fn after_login_path(&self) -> &str
Get the after-login redirect path
Sourcepub fn login_endpoint(&self) -> Option<&str>
pub fn login_endpoint(&self) -> Option<&str>
Get the login endpoint URL
Sourcepub fn logout_endpoint(&self) -> Option<&str>
pub fn logout_endpoint(&self) -> Option<&str>
Get the logout endpoint URL
Get the JWT cookie name
Sourcepub fn jwt_claims(&self) -> &[String]
pub fn jwt_claims(&self) -> &[String]
Get the list of claims to extract
Parse JWT from cookie header
Sourcepub fn decode_jwt(&self, token: &str) -> Result<JwtClaims>
pub fn decode_jwt(&self, token: &str) -> Result<JwtClaims>
Decode and validate a JWT token.
Always validates the signature. If no jwt_secret is configured, a random secret is generated at startup (logged as WARN). This means externally-signed tokens will be rejected unless the correct secret is provided.
Build Set-Cookie header for JWT token
Build Set-Cookie header to clear the JWT cookie