pub struct WhatCache { /* private fields */ }Expand description
Multi-level cache for the What framework
Implementations
Sourceimpl WhatCache
impl WhatCache
Sourcepub fn with_config(config: CacheConfig) -> Self
pub fn with_config(config: CacheConfig) -> Self
Create a cache with custom configuration
Sourcepub async fn get(&self, key: &CacheKey) -> Option<CachedValue>
pub async fn get(&self, key: &CacheKey) -> Option<CachedValue>
Get a cached page/content
Sourcepub async fn set(&self, key: &CacheKey, value: CachedValue)
pub async fn set(&self, key: &CacheKey, value: CachedValue)
Cache a page/content
Cache a page/content and associate it with tags for targeted invalidation. Tags are typically collection names (e.g., “posts”, “users”).
Sourcepub async fn set_with_ttl(
&self,
key: &CacheKey,
value: CachedValue,
_ttl: Duration,
)
pub async fn set_with_ttl( &self, key: &CacheKey, value: CachedValue, _ttl: Duration, )
Cache a page/content with custom TTL
Sourcepub async fn invalidate(&self, key: &CacheKey)
pub async fn invalidate(&self, key: &CacheKey)
Invalidate a specific cache entry
Sourcepub async fn invalidate_by_tag(&self, tag: &str)
pub async fn invalidate_by_tag(&self, tag: &str)
Invalidate all entries matching a tag. If no entries are tagged, falls back to full cache clear.
Sourcepub async fn invalidate_content_type(&self, content_type: &str)
pub async fn invalidate_content_type(&self, content_type: &str)
Invalidate all content cache entries for a specific content type / collection. Uses the tag index for targeted invalidation. If no entries are tagged, falls back to full cache clear for safety.
Sourcepub async fn invalidate_user(&self, user_id: &str)
pub async fn invalidate_user(&self, user_id: &str)
Invalidate all cache entries for a specific user. Uses prefix matching on cache keys.
Sourcepub fn stats(&self) -> CacheStats
pub fn stats(&self) -> CacheStats
Get cache statistics