pub struct RenderEngine { /* private fields */ }Expand description
Template rendering engine using html5ever for parsing
Implementations
Sourceimpl RenderEngine
impl RenderEngine
pub fn new(components: ComponentRegistry) -> Self
Sourcepub async fn render(
&self,
template: &str,
context: &HashMap<String, Value>,
) -> Result<String>
pub async fn render( &self, template: &str, context: &HashMap<String, Value>, ) -> Result<String>
Render a template with the given context
Sourcepub async fn render_with_secret(
&self,
template: &str,
context: &HashMap<String, Value>,
validation_secret: Option<&str>,
) -> Result<String>
pub async fn render_with_secret( &self, template: &str, context: &HashMap<String, Value>, validation_secret: Option<&str>, ) -> Result<String>
Render a template with an optional validation secret for form signing
Sourcepub async fn render_reactive(
&self,
template: &str,
context: &HashMap<String, Value>,
) -> Result<ReactiveReplaceResult>
pub async fn render_reactive( &self, template: &str, context: &HashMap<String, Value>, ) -> Result<ReactiveReplaceResult>
Render a template with reactive session variable wrapping Returns both the rendered HTML and the set of session keys used
Sourcepub async fn render_reactive_with_secret(
&self,
template: &str,
context: &HashMap<String, Value>,
validation_secret: Option<&str>,
) -> Result<ReactiveReplaceResult>
pub async fn render_reactive_with_secret( &self, template: &str, context: &HashMap<String, Value>, validation_secret: Option<&str>, ) -> Result<ReactiveReplaceResult>
Render reactive with optional validation secret